Index: /trunk/include/VBox/pci.h
===================================================================
--- /trunk/include/VBox/pci.h	(revision 64273)
+++ /trunk/include/VBox/pci.h	(revision 64274)
@@ -87,4 +87,5 @@
  *                          state to reflect this.
  *
+ * @param   cb              Size of the region in bytes.
  * @param   enmType         One of the PCI_ADDRESS_SPACE_* values.
  *
Index: /trunk/include/VBox/vmm/pdmstorageifs.h
===================================================================
--- /trunk/include/VBox/vmm/pdmstorageifs.h	(revision 64273)
+++ /trunk/include/VBox/vmm/pdmstorageifs.h	(revision 64274)
@@ -291,10 +291,13 @@
      * @param   enmTxDir        Direction of transfer.
      * @param   pvBuf           Pointer tp the transfer buffer.
-     * @param   cbBuf           Size of the transfer buffer.
-     * @param   pbSenseKey      Status of the command (when return value is VERR_DEV_IO_ERROR).
+     * @param   pcbBuf          Size of the transfer buffer.
+     * @param   pabSense        Status of the command (when return value is VERR_DEV_IO_ERROR).
+     * @param   cbSense         Size of the sense buffer in bytes.
      * @param   cTimeoutMillies Command timeout in milliseconds.
      * @thread  Any thread.
      */
-    DECLR3CALLBACKMEMBER(int, pfnSendCmd,(PPDMIMEDIA pInterface, const uint8_t *pbCmd, PDMMEDIATXDIR enmTxDir, void *pvBuf, uint32_t *pcbBuf, uint8_t *pabSense, size_t cbSense, uint32_t cTimeoutMillies));
+    DECLR3CALLBACKMEMBER(int, pfnSendCmd,(PPDMIMEDIA pInterface, const uint8_t *pbCmd, PDMMEDIATXDIR enmTxDir,
+                                          void *pvBuf, uint32_t *pcbBuf, uint8_t *pabSense, size_t cbSense,
+                                          uint32_t cTimeoutMillies));
 
     /**
Index: /trunk/include/VBox/vscsi.h
===================================================================
--- /trunk/include/VBox/vscsi.h	(revision 64273)
+++ /trunk/include/VBox/vscsi.h	(revision 64274)
@@ -119,6 +119,8 @@
      *
      * @returns VBox status code.
-     * @param   pInterface      Pointer to the interface structure containing the called function pointer.
-     * @param   cbIoReqAlloc    The size of the allocator specific memory in bytes.
+     * @param   hVScsiLun            Virtual SCSI LUN handle.
+     * @param   pvScsiLunUser        Opaque user data which may be used to identify the
+     *                               medium.
+     * @param   cbVScsiIoReqAlloc    The size of the allocator specific memory in bytes.
      * @thread  EMT.
      */
Index: /trunk/src/VBox/Devices/Storage/ATAPIPassthrough.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/ATAPIPassthrough.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/ATAPIPassthrough.cpp	(revision 64274)
@@ -307,4 +307,5 @@
  * @returns VBox status code.
  * @param   pTrackList    The track list to update.
+ * @param   iTrack        The first track the TOC has data for.
  * @param   fMSF          Flag whether block addresses are in MSF or LBA format.
  * @param   pbBuf         Buffer holding the formatted TOC.
Index: /trunk/src/VBox/Devices/Storage/DevAHCI.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DevAHCI.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DevAHCI.cpp	(revision 64274)
@@ -2020,5 +2020,5 @@
  * Hardware reset used for machine power on and reset.
  *
- * @param pAhciport     The port to reset.
+ * @param pAhciPort     The port to reset.
  */
 static void ahciPortHwReset(PAHCIPort pAhciPort)
@@ -2361,5 +2361,5 @@
  * @param   pvUser      User argument.
  * @param   Port        Port address where the write starts.
- * @param   pv          Where to fetch the result.
+ * @param   u32         Where to fetch the result.
  * @param   cb          Number of bytes to write.
  */
@@ -2405,5 +2405,5 @@
  * @param   pvUser      User argument.
  * @param   Port        Port address where the read starts.
- * @param   pv          Where to fetch the result.
+ * @param   pu32        Where to fetch the result.
  * @param   cb          Number of bytes to write.
  */
@@ -3570,6 +3570,4 @@
  * @returns Whether all active tasks were canceled.
  * @param   pAhciPort        The AHCI port.
- * @param   pAhciReqExcept   The given request is excepted from the cancelling
- *                           (used for error page reading).
  */
 static bool ahciCancelActiveTasks(PAHCIPort pAhciPort)
@@ -3690,4 +3688,5 @@
  * @returns nothing.
  * @param   pAhciPort    The AHCI port.
+ * @param   pAhciReq     The request to free.
  */
 static void ahciR3ReqFree(PAHCIPort pAhciPort, PAHCIREQ pAhciReq)
@@ -4026,5 +4025,7 @@
  *
  * @returns The direction of the data transfer
- * @param   pCmdHdr Pointer to the command header.
+ * @param   pAhciPort     The AHCI port of the request.
+ * @param   pAhciReq      The AHCI request state.
+ * @param   pCmdFis       Pointer to the command FIS.
  */
 static PDMMEDIAEXIOREQTYPE ahciProcessCmd(PAHCIPort pAhciPort, PAHCIREQ pAhciReq, uint8_t *pCmdFis)
@@ -4304,5 +4305,6 @@
  *
  * @returns whether the H2D FIS was successfully read from the guest memory.
- * @param pAhciReq The state of the actual task.
+ * @param pAhciPort    The AHCI port of the request.
+ * @param pAhciReq     The state of the actual task.
  */
 static bool ahciPortTaskGetCommandFis(PAHCIPort pAhciPort, PAHCIREQ pAhciReq)
@@ -5337,5 +5339,5 @@
 
 /**
- * Callback employed by ahciR3Suspend and ahciR3PowerOff..
+ * Callback employed by ahciR3Suspend and ahciR3PowerOff.
  *
  * @returns true if we've quiesced, false if we're still working.
@@ -5419,5 +5421,5 @@
  * @param   pDevIns      The device instance.
  * @param   pAhciPort    The attached device.
- * @param   szName       Name of the port to get the CFGM node.
+ * @param   pszName      Name of the port to get the CFGM node.
  */
 static int ahciR3VpdInit(PPDMDEVINS pDevIns, PAHCIPort pAhciPort, const char *pszName)
@@ -5661,7 +5663,6 @@
  * @param   pDevIns     The device instance data.
  */
-static int ahciR3ResetCommon(PPDMDEVINS pDevIns, bool fConstructor)
-{
-    RT_NOREF(fConstructor);
+static int ahciR3ResetCommon(PPDMDEVINS pDevIns)
+{
     PAHCI pAhci = PDMINS_2_DATA(pDevIns, PAHCI);
 
@@ -5688,5 +5689,5 @@
     ASMAtomicWriteBool(&pThis->fSignalIdle, false);
 
-    ahciR3ResetCommon(pDevIns, false /*fConstructor*/);
+    ahciR3ResetCommon(pDevIns);
     return true;
 }
@@ -5707,5 +5708,5 @@
     {
         ASMAtomicWriteBool(&pThis->fSignalIdle, false);
-        ahciR3ResetCommon(pDevIns, false /*fConstructor*/);
+        ahciR3ResetCommon(pDevIns);
     }
 }
@@ -6132,5 +6133,5 @@
     PDMDevHlpDBGFInfoRegister(pDevIns, szTmp, "AHCI info", ahciR3Info);
 
-    return ahciR3ResetCommon(pDevIns, true /*fConstructor*/);
+    return ahciR3ResetCommon(pDevIns);
 }
 
Index: /trunk/src/VBox/Devices/Storage/DevATA.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DevATA.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DevATA.cpp	(revision 64274)
@@ -6118,4 +6118,5 @@
  *                          I/O port, else it's a physical address.
  *                          This address is *NOT* relative to pci_mem_base like earlier!
+ * @param   cb              Size of the region in bytes.
  * @param   enmType         One of the PCI_ADDRESS_SPACE_* values.
  */
@@ -6645,5 +6646,5 @@
  * @returns true on success.
  * @returns false when one or more threads is still processing.
- * @param   pThis               Pointer to the instance data.
+ * @param   pDevIns               Pointer to the PDM device instance.
  */
 static bool ataR3AllAsyncIOIsIdle(PPDMDEVINS pDevIns)
Index: /trunk/src/VBox/Devices/Storage/DevBusLogic.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DevBusLogic.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DevBusLogic.cpp	(revision 64274)
@@ -1016,5 +1016,5 @@
  * @param   pBusLogic       Pointer to the BusLogic device instance.
  * @param   fSuppressIrq    Flag to suppress IRQ generation regardless of fIRQEnabled
- * @param   uFlag           Type of interrupt being generated.
+ * @param   uIrqType        Type of interrupt being generated.
  */
 static void buslogicSetInterrupt(PBUSLOGIC pBusLogic, bool fSuppressIrq, uint8_t uIrqType)
@@ -1047,6 +1047,6 @@
  * Deasserts the interrupt line of the BusLogic adapter.
  *
- * @returns nothing
- * @param   pBuslogic  Pointer to the BusLogic device instance.
+ * @returns nothing.
+ * @param   pBusLogic  Pointer to the BusLogic device instance.
  */
 static void buslogicClearInterrupt(PBUSLOGIC pBusLogic)
@@ -1068,4 +1068,7 @@
 /**
  * Advances the mailbox pointer to the next slot.
+ *
+ * @returns nothing.
+ * @param   pBusLogic       The BusLogic controller instance.
  */
 DECLINLINE(void) buslogicR3OutgoingMailboxAdvance(PBUSLOGIC pBusLogic)
@@ -1078,5 +1081,5 @@
  *
  * @returns nothing.
- * @param   pBusLogic.
+ * @param   pBusLogic       The BusLogic controller instance.
  */
 static void buslogicR3InitializeLocalRam(PBUSLOGIC pBusLogic)
@@ -1202,5 +1205,5 @@
  * @param   pBusLogic                 Pointer to the BusLogic device instance.
  * @param   GCPhysAddrCCB             The physical guest address of the CCB the mailbox is for.
- * @param   pCCBGuet                  The command control block.
+ * @param   pCCBGuest                 The command control block.
  * @param   uHostAdapterStatus        The host adapter status code to set.
  * @param   uDeviceStatus             The target device status to set.
@@ -1381,5 +1384,4 @@
  * @param   pCCBGuest     The CCB of the guest.
  * @param   fIs24Bit      Flag whether the 24bit SG format is used.
- * @para    cbSGEntry     Size of one SG entry in bytes.
  * @param   pcbBuf        Where to store the size of the guest data buffer on success.
  */
@@ -2496,8 +2498,8 @@
  * @param   cb          Number of bytes read.
  */
-PDMBOTHCBDECL(int) buslogicIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t *pu32, unsigned cb)
+PDMBOTHCBDECL(int) buslogicIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t *pu32, unsigned cb)
 {
     PBUSLOGIC pBusLogic = PDMINS_2_DATA(pDevIns, PBUSLOGIC);
-    unsigned iRegister = Port % 4;
+    unsigned iRegister = uPort % 4;
     RT_NOREF_PV(pvUser); RT_NOREF_PV(cb);
 
@@ -2518,8 +2520,8 @@
  * @param   cb          The value size in bytes.
  */
-PDMBOTHCBDECL(int) buslogicIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t u32, unsigned cb)
+PDMBOTHCBDECL(int) buslogicIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t u32, unsigned cb)
 {
     PBUSLOGIC pBusLogic = PDMINS_2_DATA(pDevIns, PBUSLOGIC);
-    unsigned iRegister = Port % 4;
+    unsigned iRegister = uPort % 4;
     uint8_t uVal = (uint8_t)u32;
     RT_NOREF2(pvUser, cb);
@@ -2529,6 +2531,6 @@
     int rc = buslogicRegisterWrite(pBusLogic, iRegister, (uint8_t)uVal);
 
-    Log2(("#%d %s: pvUser=%#p cb=%d u32=%#x Port=%#x rc=%Rrc\n",
-          pDevIns->iInstance, __FUNCTION__, pvUser, cb, u32, Port, rc));
+    Log2(("#%d %s: pvUser=%#p cb=%d u32=%#x uPort=%#x rc=%Rrc\n",
+          pDevIns->iInstance, __FUNCTION__, pvUser, cb, u32, uPort, rc));
 
     return rc;
@@ -2610,5 +2612,5 @@
  * @param   cb          Number of bytes read.
  */
-static DECLCALLBACK(int) buslogicR3BiosIoPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t *pu32, unsigned cb)
+static DECLCALLBACK(int) buslogicR3BiosIoPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t *pu32, unsigned cb)
 {
     RT_NOREF(pvUser, cb);
@@ -2617,8 +2619,8 @@
     Assert(cb == 1);
 
-    int rc = vboxscsiReadRegister(&pBusLogic->VBoxSCSI, (Port - BUSLOGIC_BIOS_IO_PORT), pu32);
+    int rc = vboxscsiReadRegister(&pBusLogic->VBoxSCSI, (uPort - BUSLOGIC_BIOS_IO_PORT), pu32);
 
     //Log2(("%s: pu32=%p:{%.*Rhxs} iRegister=%d rc=%Rrc\n",
-    //      __FUNCTION__, pu32, 1, pu32, (Port - BUSLOGIC_BIOS_IO_PORT), rc));
+    //      __FUNCTION__, pu32, 1, pu32, (uPort - BUSLOGIC_BIOS_IO_PORT), rc));
 
     return rc;
@@ -2636,9 +2638,9 @@
  * @param   cb          The value size in bytes.
  */
-static DECLCALLBACK(int) buslogicR3BiosIoPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t u32, unsigned cb)
+static DECLCALLBACK(int) buslogicR3BiosIoPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t u32, unsigned cb)
 {
     RT_NOREF(pvUser, cb);
     PBUSLOGIC pThis = PDMINS_2_DATA(pDevIns, PBUSLOGIC);
-    Log2(("#%d %s: pvUser=%#p cb=%d u32=%#x Port=%#x\n", pDevIns->iInstance, __FUNCTION__, pvUser, cb, u32, Port));
+    Log2(("#%d %s: pvUser=%#p cb=%d u32=%#x uPort=%#x\n", pDevIns->iInstance, __FUNCTION__, pvUser, cb, u32, uPort));
 
     /*
@@ -2651,5 +2653,5 @@
     Assert(cb == 1);
 
-    int rc = vboxscsiWriteRegister(&pThis->VBoxSCSI, (Port - BUSLOGIC_BIOS_IO_PORT), (uint8_t)u32);
+    int rc = vboxscsiWriteRegister(&pThis->VBoxSCSI, (uPort - BUSLOGIC_BIOS_IO_PORT), (uint8_t)u32);
     if (rc == VERR_MORE_DATA)
     {
@@ -3746,5 +3748,5 @@
 
 /**
- * Callback employed by buslogicR3Suspend and buslogicR3PowerOff..
+ * Callback employed by buslogicR3Suspend and buslogicR3PowerOff.
  *
  * @returns true if we've quiesced, false if we're still working.
Index: /trunk/src/VBox/Devices/Storage/DevFdc.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DevFdc.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DevFdc.cpp	(revision 64274)
@@ -2406,11 +2406,11 @@
  * @callback_method_impl{FNIOMIOPORTOUT}
  */
-static DECLCALLBACK(int) fdcIoPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t u32, unsigned cb)
+static DECLCALLBACK(int) fdcIoPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t u32, unsigned cb)
 {
     RT_NOREF(pDevIns);
     if (cb == 1)
-        fdctrl_write (pvUser, Port & 7, u32);
+        fdctrl_write (pvUser, uPort & 7, u32);
     else
-        AssertMsgFailed(("Port=%#x cb=%d u32=%#x\n", Port, cb, u32));
+        AssertMsgFailed(("uPort=%#x cb=%d u32=%#x\n", uPort, cb, u32));
     return VINF_SUCCESS;
 }
@@ -2418,12 +2418,12 @@
 
 /**
- * @callback_method_impl{FNIOMIOPORTOUT}
+ * @callback_method_impl{FNIOMIOPORTIN}
  */
-static DECLCALLBACK(int) fdcIoPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t *pu32, unsigned cb)
+static DECLCALLBACK(int) fdcIoPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t *pu32, unsigned cb)
 {
     RT_NOREF(pDevIns);
     if (cb == 1)
     {
-        *pu32 = fdctrl_read (pvUser, Port & 7);
+        *pu32 = fdctrl_read (pvUser, uPort & 7);
         return VINF_SUCCESS;
     }
Index: /trunk/src/VBox/Devices/Storage/DevLsiLogicSCSI.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DevLsiLogicSCSI.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DevLsiLogicSCSI.cpp	(revision 64274)
@@ -1688,8 +1688,8 @@
  * @callback_method_impl{FNIOMIOPORTOUT}
  */
-PDMBOTHCBDECL(int) lsilogicIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t u32, unsigned cb)
+PDMBOTHCBDECL(int) lsilogicIOPortWrite(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t u32, unsigned cb)
 {
     PLSILOGICSCSI   pThis  = PDMINS_2_DATA(pDevIns, PLSILOGICSCSI);
-    uint32_t        offReg = Port - pThis->IOPortBase;
+    uint32_t        offReg = uPort - pThis->IOPortBase;
     int             rc;
     RT_NOREF2(pvUser, cb);
@@ -1713,8 +1713,8 @@
  * @callback_method_impl{FNIOMIOPORTIN}
  */
-PDMBOTHCBDECL(int) lsilogicIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT Port, uint32_t *pu32, unsigned cb)
+PDMBOTHCBDECL(int) lsilogicIOPortRead(PPDMDEVINS pDevIns, void *pvUser, RTIOPORT uPort, uint32_t *pu32, unsigned cb)
 {
     PLSILOGICSCSI   pThis   = PDMINS_2_DATA(pDevIns, PLSILOGICSCSI);
-    uint32_t        offReg  = Port - pThis->IOPortBase;
+    uint32_t        offReg  = uPort - pThis->IOPortBase;
     RT_NOREF_PV(pvUser);
     RT_NOREF_PV(cb);
@@ -2311,5 +2311,5 @@
 
 /**
- * @interface_method_impl{PDMIMEDIA,pfnQueryDeviceLocation}
+ * @interface_method_impl{PDMIMEDIAPORT,pfnQueryDeviceLocation}
  */
 static DECLCALLBACK(int) lsilogicR3QueryDeviceLocation(PPDMIMEDIAPORT pInterface, const char **ppcszController,
@@ -2427,7 +2427,10 @@
  * @returns VINF_SUCCESS if successful
  *          VERR_NOT_FOUND if the requested page could be found.
+ * @param   pThis         The LsiLogic controller instance data.
+ * @param   pPages        The pages supported by the controller.
  * @param   u8PageNumber  Number of the page to get.
  * @param   ppPageHeader  Where to store the pointer to the page header.
  * @param   ppbPageData   Where to store the pointer to the page data.
+ * @param   pcbPage       Where to store the size of the page data in bytes on success.
  */
 static int lsilogicR3ConfigurationIOUnitPageGetFromNumber(PLSILOGICSCSI pThis,
@@ -2482,7 +2485,10 @@
  * @returns VINF_SUCCESS if successful
  *          VERR_NOT_FOUND if the requested page could be found.
+ * @param   pThis         The LsiLogic controller instance data.
+ * @param   pPages        The pages supported by the controller.
  * @param   u8PageNumber  Number of the page to get.
  * @param   ppPageHeader  Where to store the pointer to the page header.
  * @param   ppbPageData   Where to store the pointer to the page data.
+ * @param   pcbPage       Where to store the size of the page data in bytes on success.
  */
 static int lsilogicR3ConfigurationIOCPageGetFromNumber(PLSILOGICSCSI pThis,
@@ -2542,7 +2548,10 @@
  * @returns VINF_SUCCESS if successful
  *          VERR_NOT_FOUND if the requested page could be found.
+ * @param   pThis         The LsiLogic controller instance data.
+ * @param   pPages        The pages supported by the controller.
  * @param   u8PageNumber  Number of the page to get.
  * @param   ppPageHeader  Where to store the pointer to the page header.
  * @param   ppbPageData   Where to store the pointer to the page data.
+ * @param   pcbPage       Where to store the size of the page data in bytes on success.
  */
 static int lsilogicR3ConfigurationManufacturingPageGetFromNumber(PLSILOGICSCSI pThis,
@@ -2631,7 +2640,10 @@
  * @returns VINF_SUCCESS if successful
  *          VERR_NOT_FOUND if the requested page could be found.
+ * @param   pThis         The LsiLogic controller instance data.
+ * @param   pPages        The pages supported by the controller.
  * @param   u8PageNumber  Number of the page to get.
  * @param   ppPageHeader  Where to store the pointer to the page header.
  * @param   ppbPageData   Where to store the pointer to the page data.
+ * @param   pcbPage       Where to store the size of the page data in bytes on success.
  */
 static int lsilogicR3ConfigurationBiosPageGetFromNumber(PLSILOGICSCSI pThis,
@@ -2676,7 +2688,11 @@
  * @returns VINF_SUCCESS if successful
  *          VERR_NOT_FOUND if the requested page could be found.
+ * @param   pThis         The LsiLogic controller instance data.
+ * @param   pPages        The pages supported by the controller.
+ * @param   u8Port        The port to retrieve the page for.
  * @param   u8PageNumber  Number of the page to get.
  * @param   ppPageHeader  Where to store the pointer to the page header.
  * @param   ppbPageData   Where to store the pointer to the page data.
+ * @param   pcbPage       Where to store the size of the page data in bytes on success.
  */
 static int lsilogicR3ConfigurationSCSISPIPortPageGetFromNumber(PLSILOGICSCSI pThis,
@@ -2725,7 +2741,12 @@
  * @returns VINF_SUCCESS if successful
  *          VERR_NOT_FOUND if the requested page could be found.
+ * @param   pThis         The LsiLogic controller instance data.
+ * @param   pPages        The pages supported by the controller.
+ * @param   u8Bus         The bus the device is on the page should be returned.
+ * @param   u8TargetID    The target ID of the device to return the page for.
  * @param   u8PageNumber  Number of the page to get.
  * @param   ppPageHeader  Where to store the pointer to the page header.
  * @param   ppbPageData   Where to store the pointer to the page data.
+ * @param   pcbPage       Where to store the size of the page data in bytes on success.
  */
 static int lsilogicR3ConfigurationSCSISPIDevicePageGetFromNumber(PLSILOGICSCSI pThis,
@@ -2975,7 +2996,7 @@
  * @param   pThis               Pointer to the LsiLogic device state.
  * @param   pConfigurationReq   The configuration request.
- * @param   u8PageNumber        Number of the page to get.
- * @param   ppPageHeader        Where to store the pointer to the page header.
+ * @param   ppPageHeader        Where to return the pointer to the page header on success.
  * @param   ppbPageData         Where to store the pointer to the page data.
+ * @param   pcbPage             Where to store the size of the page in bytes.
  */
 static int lsilogicR3ConfigurationPageGetExtended(PLSILOGICSCSI pThis, PMptConfigurationRequest pConfigurationReq,
@@ -4957,5 +4978,5 @@
 
 /**
- * @interface_method_impl{PDMILEDPORTS,pfnQueryInterface, For a SCSI device.}
+ * @interface_method_impl{PDMILEDPORTS,pfnQueryStatusLed, For a SCSI device.}
  *
  * @remarks Called by the scsi driver, proxying the main calls.
Index: /trunk/src/VBox/Devices/Storage/DrvDiskIntegrity.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DrvDiskIntegrity.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DrvDiskIntegrity.cpp	(revision 64274)
@@ -375,5 +375,5 @@
  * @param   cSeg     Number of segments.
  * @param   off      Start offset.
- * @param   cbWrite  Number of bytes to verify.
+ * @param   cbRead   Number of bytes to verify.
  */
 static int drvdiskintReadVerify(PDRVDISKINTEGRITY pThis, PCRTSGSEG paSeg, unsigned cSeg,
Index: /trunk/src/VBox/Devices/Storage/DrvHostBase.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DrvHostBase.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DrvHostBase.cpp	(revision 64274)
@@ -133,5 +133,5 @@
 /* -=-=-=-=- IBlock -=-=-=-=- */
 
-/** @interface_method_impl{PDMIBLOCK,pfnRead} */
+/** @interface_method_impl{PDMIMEDIA,pfnRead} */
 static DECLCALLBACK(int) drvHostBaseRead(PPDMIMEDIA pInterface, uint64_t off, void *pvBuf, size_t cbRead)
 {
@@ -171,5 +171,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCK,pfnWrite} */
+/** @interface_method_impl{PDMIMEDIA,pfnWrite} */
 static DECLCALLBACK(int) drvHostBaseWrite(PPDMIMEDIA pInterface, uint64_t off, const void *pvBuf, size_t cbWrite)
 {
@@ -212,5 +212,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCK,pfnFlush} */
+/** @interface_method_impl{PDMIMEDIA,pfnFlush} */
 static DECLCALLBACK(int) drvHostBaseFlush(PPDMIMEDIA pInterface)
 {
@@ -232,5 +232,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCK,pfnIsReadOnly} */
+/** @interface_method_impl{PDMIMEDIA,pfnIsReadOnly} */
 static DECLCALLBACK(bool) drvHostBaseIsReadOnly(PPDMIMEDIA pInterface)
 {
@@ -248,5 +248,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCK,pfnGetSize} */
+/** @interface_method_impl{PDMIMEDIA,pfnGetSize} */
 static DECLCALLBACK(uint64_t) drvHostBaseGetSize(PPDMIMEDIA pInterface)
 {
@@ -264,5 +264,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCK,pfnGetType} */
+/** @interface_method_impl{PDMIMEDIA,pfnGetType} */
 static DECLCALLBACK(PDMMEDIATYPE) drvHostBaseGetType(PPDMIMEDIA pInterface)
 {
@@ -273,5 +273,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCK,pfnGetUuid} */
+/** @interface_method_impl{PDMIMEDIA,pfnGetUuid} */
 static DECLCALLBACK(int) drvHostBaseGetUuid(PPDMIMEDIA pInterface, PRTUUID pUuid)
 {
@@ -285,5 +285,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCKBIOS,pfnBiosGetPCHSGeometry} */
+/** @interface_method_impl{PDMIMEDIA,pfnBiosGetPCHSGeometry} */
 static DECLCALLBACK(int) drvHostBaseGetPCHSGeometry(PPDMIMEDIA pInterface, PPDMMEDIAGEOMETRY pPCHSGeometry)
 {
@@ -313,5 +313,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCKBIOS,pfnBiosSetPCHSGeometry} */
+/** @interface_method_impl{PDMIMEDIA,pfnBiosSetPCHSGeometry} */
 static DECLCALLBACK(int) drvHostBaseSetPCHSGeometry(PPDMIMEDIA pInterface, PCPDMMEDIAGEOMETRY pPCHSGeometry)
 {
@@ -337,5 +337,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCKBIOS,pfnGetLCHSGeometry} */
+/** @interface_method_impl{PDMIMEDIA,pfnBiosGetLCHSGeometry} */
 static DECLCALLBACK(int) drvHostBaseGetLCHSGeometry(PPDMIMEDIA pInterface, PPDMMEDIAGEOMETRY pLCHSGeometry)
 {
@@ -365,5 +365,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCKBIOS,pfnSetLCHSGeometry} */
+/** @interface_method_impl{PDMIMEDIA,pfnBiosSetLCHSGeometry} */
 static DECLCALLBACK(int) drvHostBaseSetLCHSGeometry(PPDMIMEDIA pInterface, PCPDMMEDIAGEOMETRY pLCHSGeometry)
 {
@@ -389,5 +389,5 @@
 
 
-/** @interface_method_impl{PDMIBLOCKBIOS,pfnIsVisible} */
+/** @interface_method_impl{PDMIMEDIA,pfnBiosIsVisible} */
 static DECLCALLBACK(bool) drvHostBaseIsVisible(PPDMIMEDIA pInterface)
 {
Index: /trunk/src/VBox/Devices/Storage/DrvRamDisk.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DrvRamDisk.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DrvRamDisk.cpp	(revision 64274)
@@ -309,11 +309,11 @@
 
 /**
- * Verifies a read request.
+ * Read data from the ram disk.
  *
  * @returns VBox status code.
- * @param   pThis    Disk integrity driver instance data.
+ * @param   pThis    RAM disk driver instance data.
  * @param   pSgBuf   The S/G buffer to store the data.
  * @param   off      Start offset.
- * @param   cbWrite  Number of bytes to verify.
+ * @param   cbRead   Number of bytes to read.
  */
 static int drvramdiskReadWorker(PDRVRAMDISK pThis, PRTSGBUF pSgBuf,
@@ -872,5 +872,5 @@
  *
  * @returns VBox status code.
- * @param   VINF_PDM_MEDIAEX_IOREQ_IN_PROGRESS if there is no I/O memory available to allocate and
+ * @retval  VINF_PDM_MEDIAEX_IOREQ_IN_PROGRESS if there is no I/O memory available to allocate and
  *          the request was placed on a waiting list.
  * @param   pThis     VBox disk container instance data.
@@ -1445,5 +1445,5 @@
 
 /**
- * @interface_method_impl{PDMIMEDIAEX,pfnIoReqQuerySuspendedFirst}
+ * @interface_method_impl{PDMIMEDIAEX,pfnIoReqQuerySuspendedStart}
  */
 static DECLCALLBACK(int) drvramdiskIoReqQuerySuspendedStart(PPDMIMEDIAEX pInterface, PPDMMEDIAEXIOREQ phIoReq,
Index: /trunk/src/VBox/Devices/Storage/DrvVD.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/DrvVD.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/DrvVD.cpp	(revision 64274)
@@ -71,5 +71,5 @@
  * useful for those nasty problems with the ultra-slow host filesystems.
  * If this is enabled, it can be configured via the CFGM key
- * "VBoxInternal/Devices/piix3ide/0/LUN#<x>/Config/FlushInterval". <x>
+ * "VBoxInternal/Devices/piix3ide/0/LUN#<x>/Config/FlushInterval". @verbatim<x>@endverbatim
  * must be replaced with the correct LUN number of the disk that should
  * do the periodic flushes. The value of the key is the number of bytes
@@ -83,5 +83,5 @@
  * the periodic flush cache feature above.
  * If this feature is enabled, it can be configured via the CFGM key
- * "VBoxInternal/Devices/piix3ide/0/LUN#<x>/Config/IgnoreFlush". <x>
+ * "VBoxInternal/Devices/piix3ide/0/LUN#<x>/Config/IgnoreFlush". @verbatim<x>@endverbatim
  * must be replaced with the correct LUN number of the disk that should
  * ignore flush requests. The value of the key is a boolean. The default
@@ -1349,5 +1349,5 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnSocketCreate} */
-static DECLCALLBACK(int) drvvdTcpSocketCreate(uint32_t fFlags, PVDSOCKET pSock)
+static DECLCALLBACK(int) drvvdTcpSocketCreate(uint32_t fFlags, PVDSOCKET phVdSock)
 {
     int rc = VINF_SUCCESS;
@@ -1379,5 +1379,5 @@
                 if (RT_SUCCESS(rc))
                 {
-                    *pSock = pSockInt;
+                    *phVdSock = pSockInt;
                     return VINF_SUCCESS;
                 }
@@ -1396,5 +1396,5 @@
     else
     {
-        *pSock = pSockInt;
+        *phVdSock = pSockInt;
         return VINF_SUCCESS;
     }
@@ -1406,8 +1406,8 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnSocketDestroy} */
-static DECLCALLBACK(int) drvvdTcpSocketDestroy(VDSOCKET Sock)
+static DECLCALLBACK(int) drvvdTcpSocketDestroy(VDSOCKET hVdSock)
 {
     int rc = VINF_SUCCESS;
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     /* Destroy the pipe and pollset if necessary. */
@@ -1438,9 +1438,9 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnClientConnect} */
-static DECLCALLBACK(int) drvvdTcpClientConnect(VDSOCKET Sock, const char *pszAddress, uint32_t uPort,
+static DECLCALLBACK(int) drvvdTcpClientConnect(VDSOCKET hVdSock, const char *pszAddress, uint32_t uPort,
                                                RTMSINTERVAL cMillies)
 {
     int rc = VINF_SUCCESS;
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     rc = RTTcpClientConnectEx(pszAddress, uPort, &pSockInt->hSocket, cMillies, NULL);
@@ -1466,8 +1466,8 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnClientClose} */
-static DECLCALLBACK(int) drvvdTcpClientClose(VDSOCKET Sock)
+static DECLCALLBACK(int) drvvdTcpClientClose(VDSOCKET hVdSock)
 {
     int rc = VINF_SUCCESS;
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     if (pSockInt->hPollSet != NIL_RTPOLLSET)
@@ -1484,7 +1484,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnIsClientConnected} */
-static DECLCALLBACK(bool) drvvdTcpIsClientConnected(VDSOCKET Sock)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(bool) drvvdTcpIsClientConnected(VDSOCKET hVdSock)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return pSockInt->hSocket != NIL_RTSOCKET;
@@ -1492,7 +1492,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnSelectOne} */
-static DECLCALLBACK(int) drvvdTcpSelectOne(VDSOCKET Sock, RTMSINTERVAL cMillies)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpSelectOne(VDSOCKET hVdSock, RTMSINTERVAL cMillies)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpSelectOne(pSockInt->hSocket, cMillies);
@@ -1500,7 +1500,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnRead} */
-static DECLCALLBACK(int) drvvdTcpRead(VDSOCKET Sock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpRead(VDSOCKET hVdSock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpRead(pSockInt->hSocket, pvBuffer, cbBuffer, pcbRead);
@@ -1508,7 +1508,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnWrite} */
-static DECLCALLBACK(int) drvvdTcpWrite(VDSOCKET Sock, const void *pvBuffer, size_t cbBuffer)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpWrite(VDSOCKET hVdSock, const void *pvBuffer, size_t cbBuffer)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpWrite(pSockInt->hSocket, pvBuffer, cbBuffer);
@@ -1516,7 +1516,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnSgWrite} */
-static DECLCALLBACK(int) drvvdTcpSgWrite(VDSOCKET Sock, PCRTSGBUF pSgBuf)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpSgWrite(VDSOCKET hVdSock, PCRTSGBUF pSgBuf)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpSgWrite(pSockInt->hSocket, pSgBuf);
@@ -1524,7 +1524,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnReadNB} */
-static DECLCALLBACK(int) drvvdTcpReadNB(VDSOCKET Sock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpReadNB(VDSOCKET hVdSock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpReadNB(pSockInt->hSocket, pvBuffer, cbBuffer, pcbRead);
@@ -1532,7 +1532,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnWriteNB} */
-static DECLCALLBACK(int) drvvdTcpWriteNB(VDSOCKET Sock, const void *pvBuffer, size_t cbBuffer, size_t *pcbWritten)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpWriteNB(VDSOCKET hVdSock, const void *pvBuffer, size_t cbBuffer, size_t *pcbWritten)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpWriteNB(pSockInt->hSocket, pvBuffer, cbBuffer, pcbWritten);
@@ -1540,7 +1540,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnSgWriteNB} */
-static DECLCALLBACK(int) drvvdTcpSgWriteNB(VDSOCKET Sock, PRTSGBUF pSgBuf, size_t *pcbWritten)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpSgWriteNB(VDSOCKET hVdSock, PRTSGBUF pSgBuf, size_t *pcbWritten)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpSgWriteNB(pSockInt->hSocket, pSgBuf, pcbWritten);
@@ -1548,7 +1548,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnFlush} */
-static DECLCALLBACK(int) drvvdTcpFlush(VDSOCKET Sock)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpFlush(VDSOCKET hVdSock)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpFlush(pSockInt->hSocket);
@@ -1556,7 +1556,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnSetSendCoalescing} */
-static DECLCALLBACK(int) drvvdTcpSetSendCoalescing(VDSOCKET Sock, bool fEnable)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpSetSendCoalescing(VDSOCKET hVdSock, bool fEnable)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpSetSendCoalescing(pSockInt->hSocket, fEnable);
@@ -1564,7 +1564,7 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnGetLocalAddress} */
-static DECLCALLBACK(int) drvvdTcpGetLocalAddress(VDSOCKET Sock, PRTNETADDR pAddr)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpGetLocalAddress(VDSOCKET hVdSock, PRTNETADDR pAddr)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpGetLocalAddress(pSockInt->hSocket, pAddr);
@@ -1572,12 +1572,12 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnGetPeerAddress} */
-static DECLCALLBACK(int) drvvdTcpGetPeerAddress(VDSOCKET Sock, PRTNETADDR pAddr)
-{
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+static DECLCALLBACK(int) drvvdTcpGetPeerAddress(VDSOCKET hVdSock, PRTNETADDR pAddr)
+{
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     return RTTcpGetPeerAddress(pSockInt->hSocket, pAddr);
 }
 
-static DECLCALLBACK(int) drvvdTcpSelectOneExPoll(VDSOCKET Sock, uint32_t fEvents,
+static DECLCALLBACK(int) drvvdTcpSelectOneExPoll(VDSOCKET hVdSock, uint32_t fEvents,
                                                  uint32_t *pfEvents, RTMSINTERVAL cMillies)
 {
@@ -1585,5 +1585,5 @@
     uint32_t id = 0;
     uint32_t fEventsRecv = 0;
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     *pfEvents = 0;
@@ -1654,9 +1654,9 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnSelectOneEx} */
-static DECLCALLBACK(int) drvvdTcpSelectOneExNoPoll(VDSOCKET Sock, uint32_t fEvents, uint32_t *pfEvents, RTMSINTERVAL cMillies)
+static DECLCALLBACK(int) drvvdTcpSelectOneExNoPoll(VDSOCKET hVdSock, uint32_t fEvents, uint32_t *pfEvents, RTMSINTERVAL cMillies)
 {
     RT_NOREF(cMillies); /** @todo timeouts */
     int rc = VINF_SUCCESS;
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     *pfEvents = 0;
@@ -1794,9 +1794,9 @@
 
 /** @interface_method_impl{VDINTERFACETCPNET,pfnPoke} */
-static DECLCALLBACK(int) drvvdTcpPoke(VDSOCKET Sock)
+static DECLCALLBACK(int) drvvdTcpPoke(VDSOCKET hVdSock)
 {
     int rc = VINF_SUCCESS;
     size_t cbWritten = 0;
-    PVDSOCKETINT pSockInt = (PVDSOCKETINT)Sock;
+    PVDSOCKETINT pSockInt = (PVDSOCKETINT)hVdSock;
 
     ASMAtomicXchgBool(&pSockInt->fWokenUp, true);
@@ -2465,9 +2465,9 @@
 
 /** @copydoc FNPDMBLKCACHEXFERCOMPLETEDRV */
-static DECLCALLBACK(void) drvvdBlkCacheXferCompleteIoReq(PPDMDRVINS pDrvIns, void *pvUser, int rcReq)
+static DECLCALLBACK(void) drvvdBlkCacheXferCompleteIoReq(PPDMDRVINS pDrvIns, void *pvUser, int rc)
 {
     PVBOXDISK pThis = PDMINS_2_DATA(pDrvIns, PVBOXDISK);
 
-    drvvdMediaExIoReqCompleteWorker(pThis, (PPDMMEDIAEXIOREQINT)pvUser, rcReq, true /* fUpNotify */);
+    drvvdMediaExIoReqCompleteWorker(pThis, (PPDMMEDIAEXIOREQINT)pvUser, rc, true /* fUpNotify */);
 }
 
@@ -2476,5 +2476,5 @@
                                                   PDMBLKCACHEXFERDIR enmXferDir,
                                                   uint64_t off, size_t cbXfer,
-                                                  PCRTSGBUF pcSgBuf, PPDMBLKCACHEIOXFER hIoXfer)
+                                                  PCRTSGBUF pSgBuf, PPDMBLKCACHEIOXFER hIoXfer)
 {
     int rc = VINF_SUCCESS;
@@ -2486,9 +2486,9 @@
     {
         case PDMBLKCACHEXFERDIR_READ:
-            rc = VDAsyncRead(pThis->pDisk, off, cbXfer, pcSgBuf, drvvdBlkCacheReqComplete,
+            rc = VDAsyncRead(pThis->pDisk, off, cbXfer, pSgBuf, drvvdBlkCacheReqComplete,
                              pThis, hIoXfer);
             break;
         case PDMBLKCACHEXFERDIR_WRITE:
-            rc = VDAsyncWrite(pThis->pDisk, off, cbXfer, pcSgBuf, drvvdBlkCacheReqComplete,
+            rc = VDAsyncWrite(pThis->pDisk, off, cbXfer, pSgBuf, drvvdBlkCacheReqComplete,
                               pThis, hIoXfer);
             break;
@@ -2892,5 +2892,5 @@
  *
  * @returns VBox status code.
- * @param   VINF_PDM_MEDIAEX_IOREQ_IN_PROGRESS if there is no I/O memory available to allocate and
+ * @retval  VINF_PDM_MEDIAEX_IOREQ_IN_PROGRESS if there is no I/O memory available to allocate and
  *          the request was placed on a waiting list.
  * @param   pThis     VBox disk container instance data.
@@ -3684,5 +3684,5 @@
 
 /**
- * @interface_method_impl{PDMIMEDIAEX,pfnIoReqQuerySuspendedFirst}
+ * @interface_method_impl{PDMIMEDIAEX,pfnIoReqQuerySuspendedStart}
  */
 static DECLCALLBACK(int) drvvdIoReqQuerySuspendedStart(PPDMIMEDIAEX pInterface, PPDMMEDIAEXIOREQ phIoReq,
Index: /trunk/src/VBox/Devices/Storage/HBDMgmt-darwin.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/HBDMgmt-darwin.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/HBDMgmt-darwin.cpp	(revision 64274)
@@ -242,5 +242,5 @@
  * @returns Reference to a DADissenter object which contains the result.
  * @param   hDiskRef         The disk that is about to be mounted.
- * @param   pvCOntext        Pointer to the block device manager.
+ * @param   pvContext        Pointer to the block device manager.
  */
 static DADissenterRef hbdMgrDAMountApprovalCallback(DADiskRef hDiskRef, void *pvContext)
Index: /trunk/src/VBox/Devices/Storage/HBDMgmt-win.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/HBDMgmt-win.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/HBDMgmt-win.cpp	(revision 64274)
@@ -187,5 +187,5 @@
  *
  * @returns VBox status code.
- * @param   pwszDriveWin32  The Win32 path to the block device (e.g. \\.\PhysicalDrive0 for example)
+ * @param   pwszDriveWin32  The Win32 path to the block device (e.g. "\\.\PhysicalDrive0" for example)
  * @param   ppwszDriveNt    Where to store the NT path to the volume on success.
  *                          Must be freed with RTUtf16Free().
Index: /trunk/src/VBox/Devices/Storage/IOBufMgmt.h
===================================================================
--- /trunk/src/VBox/Devices/Storage/IOBufMgmt.h	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/IOBufMgmt.h	(revision 64274)
@@ -73,5 +73,5 @@
  *
  * @returns VBox status code.
- * @param   VERR_INVALID_STATE if there is still memory allocated by the given manager.
+ * @retval  VERR_INVALID_STATE if there is still memory allocated by the given manager.
  * @param   hIoBufMgr          The I/O buffer manager.
  */
Index: /trunk/src/VBox/Devices/Storage/UsbMsd.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/UsbMsd.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/UsbMsd.cpp	(revision 64274)
@@ -1939,5 +1939,5 @@
 
 /**
- * @interface_method_impl{PDMUSBREG,pfnQueue}
+ * @interface_method_impl{PDMUSBREG,pfnUrbQueue}
  */
 static DECLCALLBACK(int) usbMsdQueue(PPDMUSBINS pUsbIns, PVUSBURB pUrb)
Index: /trunk/src/VBox/Devices/Storage/VBoxSCSI.cpp
===================================================================
--- /trunk/src/VBox/Devices/Storage/VBoxSCSI.cpp	(revision 64273)
+++ /trunk/src/VBox/Devices/Storage/VBoxSCSI.cpp	(revision 64274)
@@ -277,5 +277,5 @@
  * @returns VBox status code.
  * @param   pVBoxSCSI      Pointer to the SCSI state.
- * @paam    puLun          Where to store the LUN on success.
+ * @param   puLun          Where to store the LUN on success.
  * @param   ppbCdb         Where to store the pointer to the CDB on success.
  * @param   pcbCdb         Where to store the size of the CDB on success.

Index: /trunk/include/VBox/vd-ifs.h
===================================================================
--- /trunk/include/VBox/vd-ifs.h	(revision 64273)
+++ /trunk/include/VBox/vd-ifs.h	(revision 64274)
@@ -1152,7 +1152,7 @@
      * @retval  VERR_NOT_SUPPORTED if the combination of flags is not supported.
      * @param   fFlags    Combination of the VD_INTERFACETCPNET_CONNECT_* \#defines.
-     * @param   pSock     Where to store the handle.
-     */
-    DECLR3CALLBACKMEMBER(int, pfnSocketCreate, (uint32_t fFlags, PVDSOCKET pSock));
+     * @param   phVdSock  Where to store the handle.
+     */
+    DECLR3CALLBACKMEMBER(int, pfnSocketCreate, (uint32_t fFlags, PVDSOCKET phVdSock));
 
     /**
@@ -1160,7 +1160,7 @@
      *
      * @return iprt status code.
-     * @param  Sock       Socket handle (/ pointer).
-     */
-    DECLR3CALLBACKMEMBER(int, pfnSocketDestroy, (VDSOCKET Sock));
+     * @param  hVdSock    Socket handle (/ pointer).
+     */
+    DECLR3CALLBACKMEMBER(int, pfnSocketDestroy, (VDSOCKET hVdSock));
 
     /**
@@ -1168,5 +1168,5 @@
      *
      * @return  iprt status code.
      * @param   Sock            Socket handle (/ pointer)..
      * @param   pszAddress      The address to connect to.
      * @param   uPort           The port to connect to.
@@ -1176,5 +1176,5 @@
      *                          configured on the running system.
      */
-    DECLR3CALLBACKMEMBER(int, pfnClientConnect, (VDSOCKET Sock, const char *pszAddress, uint32_t uPort,
+    DECLR3CALLBACKMEMBER(int, pfnClientConnect, (VDSOCKET hVdSock, const char *pszAddress, uint32_t uPort,
                                                  RTMSINTERVAL cMillies));
 
@@ -1183,7 +1183,7 @@
      *
      * @return  iprt status code.
-     * @param   Sock            Socket handle (/ pointer).
-     */
-    DECLR3CALLBACKMEMBER(int, pfnClientClose, (VDSOCKET Sock));
+     * @param   hVdSock         Socket handle (/ pointer).
+     */
+    DECLR3CALLBACKMEMBER(int, pfnClientClose, (VDSOCKET hVdSock));
 
     /**
@@ -1192,7 +1192,7 @@
      * @returns true if the socket is connected.
      *          false otherwise.
-     * @param   Sock        Socket handle (/ pointer).
-     */
-    DECLR3CALLBACKMEMBER(bool, pfnIsClientConnected, (VDSOCKET Sock));
+     * @param   hVdSock     Socket handle (/ pointer).
+     */
+    DECLR3CALLBACKMEMBER(bool, pfnIsClientConnected, (VDSOCKET hVdSock));
 
     /**
@@ -1201,9 +1201,9 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   cMillies    Number of milliseconds to wait for the socket.
      *                      Use RT_INDEFINITE_WAIT to wait for ever.
      */
-    DECLR3CALLBACKMEMBER(int, pfnSelectOne, (VDSOCKET Sock, RTMSINTERVAL cMillies));
+    DECLR3CALLBACKMEMBER(int, pfnSelectOne, (VDSOCKET hVdSock, RTMSINTERVAL cMillies));
 
     /**
@@ -1211,5 +1211,5 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   pvBuffer    Where to put the data we read.
      * @param   cbBuffer    Read buffer size.
@@ -1218,5 +1218,5 @@
      *                      If not NULL a partial read can be done successfully.
      */
-    DECLR3CALLBACKMEMBER(int, pfnRead, (VDSOCKET Sock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead));
+    DECLR3CALLBACKMEMBER(int, pfnRead, (VDSOCKET hVdSock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead));
 
     /**
@@ -1224,9 +1224,9 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   pvBuffer    Buffer to write data to socket.
      * @param   cbBuffer    How much to write.
      */
-    DECLR3CALLBACKMEMBER(int, pfnWrite, (VDSOCKET Sock, const void *pvBuffer, size_t cbBuffer));
+    DECLR3CALLBACKMEMBER(int, pfnWrite, (VDSOCKET hVdSock, const void *pvBuffer, size_t cbBuffer));
 
     /**
@@ -1234,8 +1234,8 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
-     * @param   pSgBuffer   Scatter/gather buffer to write data to socket.
-     */
-    DECLR3CALLBACKMEMBER(int, pfnSgWrite, (VDSOCKET Sock, PCRTSGBUF pSgBuffer));
+     * @param   hVdSock     Socket handle (/ pointer).
+     * @param   pSgBuf      Scatter/gather buffer to write data to socket.
+     */
+    DECLR3CALLBACKMEMBER(int, pfnSgWrite, (VDSOCKET hVdSock, PCRTSGBUF pSgBuf));
 
     /**
@@ -1243,10 +1243,10 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   pvBuffer    Where to put the data we read.
      * @param   cbBuffer    Read buffer size.
      * @param   pcbRead     Number of bytes read.
      */
-    DECLR3CALLBACKMEMBER(int, pfnReadNB, (VDSOCKET Sock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead));
+    DECLR3CALLBACKMEMBER(int, pfnReadNB, (VDSOCKET hVdSock, void *pvBuffer, size_t cbBuffer, size_t *pcbRead));
 
     /**
@@ -1254,10 +1254,10 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   pvBuffer    Buffer to write data to socket.
      * @param   cbBuffer    How much to write.
      * @param   pcbWritten  Number of bytes written.
      */
-    DECLR3CALLBACKMEMBER(int, pfnWriteNB, (VDSOCKET Sock, const void *pvBuffer, size_t cbBuffer, size_t *pcbWritten));
+    DECLR3CALLBACKMEMBER(int, pfnWriteNB, (VDSOCKET hVdSock, const void *pvBuffer, size_t cbBuffer, size_t *pcbWritten));
 
     /**
@@ -1265,9 +1265,9 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   pSgBuffer   Scatter/gather buffer to write data to socket.
      * @param   pcbWritten  Number of bytes written.
      */
-    DECLR3CALLBACKMEMBER(int, pfnSgWriteNB, (VDSOCKET Sock, PRTSGBUF pSgBuffer, size_t *pcbWritten));
+    DECLR3CALLBACKMEMBER(int, pfnSgWriteNB, (VDSOCKET hVdSock, PRTSGBUF pSgBuf, size_t *pcbWritten));
 
     /**
@@ -1275,7 +1275,7 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
-     */
-    DECLR3CALLBACKMEMBER(int, pfnFlush, (VDSOCKET Sock));
+     * @param   hVdSock     Socket handle (/ pointer).
+     */
+    DECLR3CALLBACKMEMBER(int, pfnFlush, (VDSOCKET hVdSock));
 
     /**
@@ -1283,8 +1283,8 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   fEnable     When set to true enables coalescing.
      */
-    DECLR3CALLBACKMEMBER(int, pfnSetSendCoalescing, (VDSOCKET Sock, bool fEnable));
+    DECLR3CALLBACKMEMBER(int, pfnSetSendCoalescing, (VDSOCKET hVdSock, bool fEnable));
 
     /**
@@ -1292,8 +1292,8 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   pAddr       Where to store the local address on success.
      */
-    DECLR3CALLBACKMEMBER(int, pfnGetLocalAddress, (VDSOCKET Sock, PRTNETADDR pAddr));
+    DECLR3CALLBACKMEMBER(int, pfnGetLocalAddress, (VDSOCKET hVdSock, PRTNETADDR pAddr));
 
     /**
@@ -1301,8 +1301,8 @@
      *
      * @return  iprt status code.
      * @param   Sock        Socket handle (/ pointer).
      * @param   pAddr       Where to store the peer address on success.
      */
-    DECLR3CALLBACKMEMBER(int, pfnGetPeerAddress, (VDSOCKET Sock, PRTNETADDR pAddr));
+    DECLR3CALLBACKMEMBER(int, pfnGetPeerAddress, (VDSOCKET hVdSock, PRTNETADDR pAddr));
 
     /**
@@ -1318,5 +1318,5 @@
      *                      Use RT_INDEFINITE_WAIT to wait for ever.
      */
-    DECLR3CALLBACKMEMBER(int, pfnSelectOneEx, (VDSOCKET Sock, uint32_t fEvents,
+    DECLR3CALLBACKMEMBER(int, pfnSelectOneEx, (VDSOCKET hVdSock, uint32_t fEvents,
                                                uint32_t *pfEvents, RTMSINTERVAL cMillies));
 
@@ -1327,5 +1327,5 @@
      * @param  hVdSock      VD Socket handle(/pointer).
      */
-    DECLR3CALLBACKMEMBER(int, pfnPoke, (VDSOCKET Sock));
+    DECLR3CALLBACKMEMBER(int, pfnPoke, (VDSOCKET hVdSock));
 
 } VDINTERFACETCPNET, *PVDINTERFACETCPNET;
@@ -1168,5 +1168,5 @@
      *
      * @return  iprt status code.
-     * @param   Sock            Socket handle (/ pointer)..
+     * @param   hVdSock         Socket handle (/ pointer)..
      * @param   pszAddress      The address to connect to.
      * @param   uPort           The port to connect to.
@@ -1201,9 +1201,9 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
+     * @param   hVdSock     Socket handle (/ pointer).
      * @param   cMillies    Number of milliseconds to wait for the socket.
      *                      Use RT_INDEFINITE_WAIT to wait for ever.
@@ -1211,5 +1211,5 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
+     * @param   hVdSock     Socket handle (/ pointer).
      * @param   pvBuffer    Where to put the data we read.
      * @param   cbBuffer    Read buffer size.
@@ -1224,9 +1224,9 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
+     * @param   hVdSock     Socket handle (/ pointer).
      * @param   pvBuffer    Buffer to write data to socket.
      * @param   cbBuffer    How much to write.
@@ -1243,10 +1243,10 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
+     * @param   hVdSock     Socket handle (/ pointer).
      * @param   pvBuffer    Where to put the data we read.
      * @param   cbBuffer    Read buffer size.
@@ -1254,10 +1254,10 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
+     * @param   hVdSock     Socket handle (/ pointer).
      * @param   pvBuffer    Buffer to write data to socket.
      * @param   cbBuffer    How much to write.
@@ -1265,9 +1265,9 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
-     * @param   pSgBuffer   Scatter/gather buffer to write data to socket.
+     * @param   hVdSock     Socket handle (/ pointer).
+     * @param   pSgBuf      Scatter/gather buffer to write data to socket.
      * @param   pcbWritten  Number of bytes written.
      */
@@ -1283,8 +1283,8 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
+     * @param   hVdSock     Socket handle (/ pointer).
      * @param   fEnable     When set to true enables coalescing.
      */
@@ -1292,8 +1292,8 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
+     * @param   hVdSock     Socket handle (/ pointer).
      * @param   pAddr       Where to store the local address on success.
      */
@@ -1301,8 +1301,8 @@
      *
      * @return  iprt status code.
-     * @param   Sock        Socket handle (/ pointer).
+     * @param   hVdSock     Socket handle (/ pointer).
      * @param   pAddr       Where to store the peer address on success.
      */